@@ -6,6 +6,8 @@ DatosList = []
 
 #https://widdowquinn.github.io/coding/update-pypi-package/
 
+#_print_Symbol
+
 def Inicializar(n):
   global DatosList,Orden,Estilo
 
@@ -22,18 +24,18 @@ def Inicializar(n):
   Orden = 8
   return DatosList,Orden
 
-def Busqueda(symbolo):
+def search(symbolo):
   for c_element in DatosList:
     if c_element[0] == symbolo:
       if isinstance(c_element[1],float):#Si tenemos un numero
-          return sympy.symbols("("+str(c_element[1])+")")
+          return "("+str(c_element[1])+")"
       elif isinstance(c_element[1],int):#Si tenemos un float
-          return sympy.symbols("("+str(c_element[1])+")")
+          return "("+str(c_element[1])+")"
       elif c_element[1] != None:#Si tenemos una expresión
-          return c_element[1]
+          return sympy.latex(c_element[1])
       else:
-        return symbolo#Si es None
-  return symbolo
+        return sy.latex(symbolo)#Si es None
+  return sy.latex(symbolo)
 
 def Redondear(expr):#Redondeamos la expresión.
   if isinstance(expr, sympy.Expr) or isinstance(expr, sympy.Float):
